@@ -6,9 +6,9 @@ class ExamplesTestCase(unittest.TestCase):
     def setUp(self):
         from .. import get_storage_model
         try:
-            _ = get_storage_model()
+            get_storage_model()
         except ImportError:
-            raise unittest.SkipTest
+            raise unittest.SkipTest()
 
     def test_devlist_runs(self):
         from . import devlist
